@@ -25,6 +25,7 @@
 #include <proton/import_export.h>
 #include <proton/type_compat.h>
 #include <proton/condition.h>
+#include <proton/logger.h>
 #include <stddef.h>
 
 #ifdef __cplusplus
@@ -226,6 +227,19 @@ PN_EXTERN bool pn_transport_is_encrypted(pn_transport_t *transport);
  */
 PN_EXTERN pn_condition_t *pn_transport_condition(pn_transport_t *transport);
 
+/**
+ * Get the transport logger
+ *
+ * This can be used to control the logging information emitted by the transport
+ *
+ * The pointer returned by this operation is valid until the
+ * transport object is freed.
+ *
+ * @param[in] transport the transport object
+ * @return the transport's logger object
+ */
+PN_EXTERN pn_logger_t *pn_transport_logger(pn_transport_t *transport);
+
 /**
  * **Deprecated** - Use ::pn_transport_condition().
  */
@@ -681,7 +695,7 @@ PN_EXTERN bool pn_transport_closed(pn_transport_t *transport);
  *
  * @param[in] transport the transport to process.
  * @param[in] now A monotonically-increasing time value in milliseconds.
- *   Does not need to be wall-clock time or a valid AMQP timestamp, but must increase montonically.
+ *   Does not need to be wall-clock time or a valid AMQP timestamp, but must increase monotonically.
  *
  * @return If non-zero, then the monotonic expiration time of the next pending
  * timer event for the transport.  The caller must invoke pn_transport_tick
